==> chaosmesh-model-6.6.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/PodChaosFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PodChaosFluentImpl<A extends PodChaosFluent<A>> extends BaseFluent<A> implements PodChaosFluent<A>{
  public PodChaosFluentImpl() {
  }
  public PodChaosFluentImpl(PodChaos instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private PodChaosSpecBuilder spec;
  private PodChaosStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public PodChaosFluent.MetadataNested<A> withNewMetadata() {
    return new PodChaosFluentImpl.MetadataNestedImpl();
  }
  public PodChaosFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new PodChaosFluentImpl.MetadataNestedImpl(item);
  }
  public PodChaosFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public PodChaosFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public PodChaosFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodChaosSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public PodChaosSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(PodChaosSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new PodChaosSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public PodChaosFluent.SpecNested<A> withNewSpec() {
    return new PodChaosFluentImpl.SpecNestedImpl();
  }
  public PodChaosFluent.SpecNested<A> withNewSpecLike(PodChaosSpec item) {
    return new PodChaosFluentImpl.SpecNestedImpl(item);
  }
  public PodChaosFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public PodChaosFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new PodChaosSpecBuilder().build());
  }
  public PodChaosFluent.SpecNested<A> editOrNewSpecLike(PodChaosSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodChaosStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public PodChaosStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(PodChaosStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new PodChaosStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public PodChaosFluent.StatusNested<A> withNewStatus() {
    return new PodChaosFluentImpl.StatusNestedImpl();
  }
  public PodChaosFluent.StatusNested<A> withNewStatusLike(PodChaosStatus item) {
    return new PodChaosFluentImpl.StatusNestedImpl(item);
  }
  public PodChaosFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public PodChaosFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new PodChaosStatusBuilder().build());
  }
  public PodChaosFluent.StatusNested<A> editOrNewStatusLike(PodChaosStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PodChaosFluentImpl that = (PodChaosFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<PodChaosFluent.MetadataNested<N>> implements PodChaosFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) PodChaosFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends PodChaosSpecFluentImpl<PodChaosFluent.SpecNested<N>> implements PodChaosFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(PodChaosSpec item) {
      this.builder = new PodChaosSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new PodChaosSpecBuilder(this);
    }
    PodChaosSpecBuilder builder;
    public N and() {
      return (N) PodChaosFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends PodChaosStatusFluentImpl<PodChaosFluent.StatusNested<N>> implements PodChaosFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(PodChaosStatus item) {
      this.builder = new PodChaosStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new PodChaosStatusBuilder(this);
    }
    PodChaosStatusBuilder builder;
    public N and() {
      return (N) PodChaosFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> chaosmesh-model-6.7.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/PodChaosFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PodChaosFluentImpl<A extends PodChaosFluent<A>> extends BaseFluent<A> implements PodChaosFluent<A>{
  public PodChaosFluentImpl() {
  }
  public PodChaosFluentImpl(PodChaos instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private PodChaosSpecBuilder spec;
  private PodChaosStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public PodChaosFluentImpl.MetadataNested<A> withNewMetadata() {
    return new PodChaosFluentImpl.MetadataNestedImpl();
  }
  public PodChaosFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new PodChaosFluentImpl.MetadataNestedImpl(item);
  }
  public PodChaosFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public PodChaosFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public PodChaosFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodChaosSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public PodChaosSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(PodChaosSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new PodChaosSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public PodChaosFluentImpl.SpecNested<A> withNewSpec() {
    return new PodChaosFluentImpl.SpecNestedImpl();
  }
  public PodChaosFluentImpl.SpecNested<A> withNewSpecLike(PodChaosSpec item) {
    return new PodChaosFluentImpl.SpecNestedImpl(item);
  }
  public PodChaosFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public PodChaosFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new PodChaosSpecBuilder().build());
  }
  public PodChaosFluentImpl.SpecNested<A> editOrNewSpecLike(PodChaosSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodChaosStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public PodChaosStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(PodChaosStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new PodChaosStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public PodChaosFluentImpl.StatusNested<A> withNewStatus() {
    return new PodChaosFluentImpl.StatusNestedImpl();
  }
  public PodChaosFluentImpl.StatusNested<A> withNewStatusLike(PodChaosStatus item) {
    return new PodChaosFluentImpl.StatusNestedImpl(item);
  }
  public PodChaosFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public PodChaosFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new PodChaosStatusBuilder().build());
  }
  public PodChaosFluentImpl.StatusNested<A> editOrNewStatusLike(PodChaosStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PodChaosFluentImpl that = (PodChaosFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<PodChaosFluentImpl.MetadataNested<N>> implements PodChaosFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) PodChaosFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends PodChaosSpecFluentImpl<PodChaosFluentImpl.SpecNested<N>> implements PodChaosFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(PodChaosSpec item) {
      this.builder = new PodChaosSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new PodChaosSpecBuilder(this);
    }
    PodChaosSpecBuilder builder;
    public N and() {
      return (N) PodChaosFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends PodChaosStatusFluentImpl<PodChaosFluentImpl.StatusNested<N>> implements PodChaosFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(PodChaosStatus item) {
      this.builder = new PodChaosStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new PodChaosStatusBuilder(this);
    }
    PodChaosStatusBuilder builder;
    public N and() {
      return (N) PodChaosFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
